# -*- coding: utf-8 -*-
# (c) 2013 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com
import os


__version__ = '1.0.0'


def import_descendants(parent_module, target_globals, target_locals):
    """
    `import *` from all descendant modules of a module.

    src_module: the module whose descendants are to be imported
    target_globals: the target's globals()
     (target means 'place where the imports should be imported to)
    target_locals: the target's locals()
    """
    basedir = os.path.dirname(parent_module.__file__)

    for root_dir, dirs, files in os.walk(basedir):
        relative_dir = root_dir[len(basedir):]
        package = parent_module.__package__ + relative_dir.replace(os.path.sep, '.')
        components = [os.path.splitext(filename) for filename in files]
        modules = [basename for basename, ext in components
                   if ext == '.py' and basename != '__init__']

        # Import the directory module, unless it is src_module itself (this
        # function is commonly used to import the descendants of a module into
        # itself, so if we didn't have this guard then we'd try to import the
        # parent module into itself)
        if root_dir != basedir:
            exec 'from %s import *' % (package,) in target_globals, target_locals

        for module in modules:
            exec 'from %s.%s import *' % (package, module) in target_globals, target_locals



# -*- coding: utf-8 -*-
# (c) 2013 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com


CONSTANT_IN_GRANDCHILD_FILE = 'in grandchild file'



# -*- coding: utf-8 -*-
# (c) 2013 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com
from import_descendants import import_descendants
import sys

this_module = sys.modules[__name__]
import_descendants(this_module, globals(), locals())



# -*- coding: utf-8 -*-
# (c) 2013 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com
#from django.db import models

# Create your models here.



# -*- coding: utf-8 -*-
# (c) 2013 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com

"""
Tests for import_descendants.
"""

from django.test import TestCase


class SimpleTest(TestCase):
    def test_child_file_imported(self):
        from import_descendants.test_example import CONSTANT_IN_CHILD_FILE
        self.assertEqual('in child file', CONSTANT_IN_CHILD_FILE)

    def test_child_dir_imported(self):
        from import_descendants.test_example import CONSTANT_IN_CHILD_DIR
        self.assertEqual('in child dir', CONSTANT_IN_CHILD_DIR)

    def test_grandchild_file_imported(self):
        from import_descendants.test_example import CONSTANT_IN_GRANDCHILD_FILE
        self.assertEqual('in grandchild file', CONSTANT_IN_GRANDCHILD_FILE)

    def test_grandchild_dir_imported(self):
        from import_descendants.test_example import CONSTANT_IN_GRANDCHILD_DIR
        self.assertEqual('in grandchild dir', CONSTANT_IN_GRANDCHILD_DIR)
